run

Function run 

pub async fn run(config: ServerConfig) -> Result<()>
Start the server with the default user-facing output behavior.

This is the right entrypoint for binaries such as tael serve: it installs a default tracing subscriber if the process has not already done so and prints a startup banner to stdout.