pub struct LogRecord {
pub timestamp: DateTime<Utc>,
pub observed_timestamp: DateTime<Utc>,
pub trace_id: Option<String>,
pub span_id: Option<String>,
pub severity: LogSeverity,
pub severity_text: String,
pub body: String,
pub service: String,
pub attributes: HashMap<String, String>,
pub body_sha256: Option<String>,
}Fields
timestamp: DateTime<Utc>observed_timestamp: DateTime<Utc>trace_id: Option<String>span_id: Option<String>severity: LogSeverityseverity_text: Stringbody: StringThe log body. For oversized bodies this is emptied at ingestion and the
content moved to the blob store, referenced by Self::body_sha256.
service: Stringattributes: HashMap<String, String>body_sha256: Option<String>Set when the body was offloaded to the content-addressed blob store
(large bodies, e.g. stack traces). Resolve via the blob store to get
the original text. None for inline bodies.