pub struct ServerConfig {
pub otlp_grpc_addr: String,
pub rest_api_addr: String,
pub rest_api_socket: Option<String>,
pub data_dir: String,
pub wal_dir: String,
pub storage: StorageBackend,
pub query_shards: Vec<String>,
pub wal_standbys: Vec<String>,
pub wal_required_acks: Option<usize>,
pub cluster: Option<ClusterSettings>,
}Fields
otlp_grpc_addr: Stringrest_api_addr: Stringrest_api_socket: Option<String>data_dir: Stringwal_dir: Stringstorage: StorageBackendquery_shards: Vec<String>When non-empty, this process runs as a stateless query tier: reads
are served by a FanoutStore that scatter-gathers across these shard
base URLs (http://shard-0:7701,...) instead of a local engine. Set via
TAEL_QUERY_SHARDS. See docs/tael-server-scaling-ha.md 3.
wal_standbys: Vec<String>Standby base URLs this node ships its WAL to as a leader
(http://standby-1:7701,...). Set via TAEL_WAL_STANDBYS. Only honored
by the tael-backend engine. See 5.1.
wal_required_acks: Option<usize>How many standbys must ack a write before it returns. None = all
(fully synchronous); Some(0) = async best-effort. Set via
TAEL_WAL_REQUIRED_ACKS.
cluster: Option<ClusterSettings>Cluster coordination (chitchat) for automatic leader election + epoch
fencing of WAL replication. Some when TAEL_CLUSTER_LISTEN is set.
See docs/tael-server-scaling-ha.md 5.1.
Implementations
Sourceimpl ServerConfig
impl ServerConfig